@@ -5,23 +5,25 @@
 #
 # This module implements some useful stuff when programming with RDFLib.
 
-from rdfhelpers.rdfhelpers import graphFrom, expandQName, URI, getvalue, setvalue
+from rdfhelpers.rdfhelpers import expandQName, URI, getvalue, setvalue
 from rdfhelpers.rdfhelpers import isContainerItemPredicate, makeContainerItemPredicate, diff
-from rdfhelpers.rdfhelpers import cbd, cbdAnalysis
+from rdfhelpers.cbd import cbd, reverse_cbd
 from rdfhelpers.rdfhelpers import getContainerStatements, getContainerItems, setContainerItems
-from rdfhelpers.rdfhelpers import SPARQLRepository, JournaledGraph, FocusedGraph, CBDGraph
-from rdfhelpers.templated import identity, mapDict, Templated, TemplatedQueryMixin
+from rdfhelpers.rdfhelpers import SPARQLRepository, FocusedGraph, CBDGraph
+from rdfhelpers.templated import graphFrom, identity, mapDict
+from rdfhelpers.templated import Templated, Composable
 from rdfhelpers.constructor import Constructor
 from rdfhelpers.labels import LabelCache, SKOSLabelCache
 from rdfhelpers.gsp import GraphStoreClient
 
 __all__ = [
-    'graphFrom', 'expandQName', 'URI', 'getvalue', 'setvalue',
+    'expandQName', 'URI', 'getvalue', 'setvalue',
     'isContainerItemPredicate', 'makeContainerItemPredicate', 'diff',
-    'cbd', 'cbdAnalysis',
+    'cbd', "reverse_cbd",
     'getContainerStatements', 'getContainerItems', 'setContainerItems',
-    'SPARQLRepository', 'JournaledGraph', 'FocusedGraph', 'CBDGraph',
-    'identity', 'mapDict', 'Templated', 'TemplatedQueryMixin',
+    'SPARQLRepository', 'FocusedGraph', 'CBDGraph',
+    'graphFrom', 'identity', 'mapDict',
+    'Templated', 'Composable',
     'Constructor',
     'LabelCache', 'SKOSLabelCache',
     'GraphStoreClient'
